@@ -25,13 +25,13 @@ class TriggerImportDataBaseResource(Resource):
     
     def get(self):
         try:
-            task_url    = analytics_conf.ANALYTICS_BASE_URL + self.get_task_url()
+            task_url    = analytics_conf.UPSTREAM_BASE_URL + self.get_task_url()
             queue_name  = self.get_task_queue()
             payload     = self.get_data_payload()or {}
             
-            current_app.logger.debug('task_url=%s', task_url)
-            current_app.logger.debug('queue_name=%s', queue_name)
-            current_app.logger.debug('payload=%s', payload)
+            logger.debug('task_url=%s', task_url)
+            logger.debug('queue_name=%s', queue_name)
+            logger.debug('payload=%s', payload)
             
             payload['batch_id'] = random_string(8, is_human_mistake_safe=True)
             
@@ -39,7 +39,7 @@ class TriggerImportDataBaseResource(Resource):
                         http_method = self.get_task_http_method(), payload=payload,
                         )
         except:
-            current_app.logger.debug(get_tracelog())
+            logger.debug(get_tracelog())
         
         return self.output_html("Triggered task_url=%s"% (task_url))
     
@@ -101,11 +101,11 @@ class InitImportDataBaseResource(TriggerImportDataBaseResource):
                     
                     task_url    = self.get_task_url()
                     if task_url:
-                        task_url    = analytics_conf.ANALYTICS_BASE_URL + task_url
+                        task_url    = analytics_conf.UPSTREAM_BASE_URL + task_url
                         queue_name  = self.get_task_queue()
                         
-                        current_app.logger.debug('InitImportDataBaseResource: task_url=%s', task_url)
-                        current_app.logger.debug('InitImportDataBaseResource: queue_name=%s', queue_name)
+                        logger.debug('InitImportDataBaseResource: task_url=%s', task_url)
+                        logger.debug('InitImportDataBaseResource: queue_name=%s', queue_name)
                         
                         create_task(task_url, queue_name, payload=payload, 
                                     in_seconds=self.get_task_delay_in_seconds(), 
@@ -117,7 +117,7 @@ class InitImportDataBaseResource(TriggerImportDataBaseResource):
                     logger.debug(get_tracelog())
                     return
         except:
-            current_app.logger.error('Faield due to %s', get_tracelog()) 
+            logger.error('Faield due to %s', get_tracelog()) 
         
         return self.output_html("Init %s" % task_url)
         
@@ -197,7 +197,7 @@ class ImportDataBaseResource(InitImportDataBaseResource):
             
             logger.debug('>>>>>>>>>>>>>>>>>>>>>>>>>>> updated existing_playload=%s', existing_playload)
             
-            task_url    = analytics_conf.ANALYTICS_BASE_URL + self.get_task_url()
+            task_url    = analytics_conf.UPSTREAM_BASE_URL + self.get_task_url()
             queue_name  = self.get_task_queue()
             
             logger.debug('ImportDataBaseResource: task_url=%s', task_url)
